Dir

Struct Dir 

pub struct Dir<T: Scalar, const N: usize, S: Space>(/* private fields */);
A direction in N-dimensional space, represented by a unit vector.

The API of this type is fairly limited to ensure it always contains a unit vector.

Implementations

Source

impl<T: Scalar, const N: usize, S: Space> Dir<T, N, S>

pub fn from_vec(v: Vector<T, N, S>) -> Self
where T: Float,

Returns the direction of the given vector. If v is the null vector, this function panics.

pub fn from_unit_vec_unchecked(v: Vector<T, N, S>) -> Self

Returns the wrapped input vector, assuming it is normalized.

pub fn to_unit_vec(&self) -> Vector<T, N, S>

Returns the unit vector that represents this direction.

pub fn to_point(&self) -> Point<T, N, S>

Returns the point corresponding to this unit vector (a point on the unit sphere).

pub fn in_space<Target: Space>(self) -> Dir<T, N, Target>

Reinterprets this direction as being in the space Target instead of S. Before calling this, make sure this operation makes semantic sense and don’t just use it to get rid of compiler errors.

pub fn to_f32(self) -> Dir<f32, N, S>
where T: NumCast,

Casts self to using f32 as scalar.

pub fn to_f64(self) -> Dir<f64, N, S>
where T: NumCast,

Casts self to using f64 as scalar.

pub fn as_bytes(&self) -> &[u8]

Returns a byte slice of the unit vector representing this direction. Useful to pass to graphics APIs.

pub fn to_array(self) -> [T; N]

Returns the components of this unit vector as arary.

Source

impl<T: Scalar, S: Space> Dir<T, 2, S>

pub fn new(x: T, y: T) -> Self
where T: Float,

Creates a Dir by normalizing the vector specified by the given coordinates.

pub const fn new_unchecked(x: T, y: T) -> Self

Creates a Dir without checking that the given values form a unit vector.

pub fn unit_x() -> Self

Returns (1, 0, 0).

pub fn unit_y() -> Self

Returns (0, 1, 0).

pub fn x(&self) -> T

Returns the x coordinate.

pub fn y(&self) -> T

Returns the y coordinate.

Source

impl<T: Scalar, S: Space> Dir<T, 3, S>

pub fn new(x: T, y: T, z: T) -> Self
where T: Float,

Creates a Dir by normalizing the vector specified by the given coordinates.

pub const fn new_unchecked(x: T, y: T, z: T) -> Self

Creates a Dir without checking that the given values form a unit vector.

pub fn unit_x() -> Self

Returns (1, 0, 0).

pub fn unit_y() -> Self

Returns (0, 1, 0).

pub fn unit_z() -> Self

Returns (0, 0, 1).

pub fn x(&self) -> T

Returns the x coordinate.

pub fn y(&self) -> T

Returns the y coordinate.

pub fn z(&self) -> T

Returns the z coordinate.