pub struct Dir<T: Scalar, const N: usize, S: Space>(/* private fields */);Expand description
A direction in N-dimensional space, represented by a unit vector.
The API of this type is fairly limited to ensure it always contains a unit vector.
Implementations
Sourceimpl<T: Scalar, const N: usize, S: Space> Dir<T, N, S>
impl<T: Scalar, const N: usize, S: Space> Dir<T, N, S>
Sourcepub fn from_vec(v: Vector<T, N, S>) -> Selfwhere
T: Float,
pub fn from_vec(v: Vector<T, N, S>) -> Selfwhere
T: Float,
Returns the direction of the given vector. If v is the null vector,
this function panics.
Sourcepub fn from_unit_vec_unchecked(v: Vector<T, N, S>) -> Self
pub fn from_unit_vec_unchecked(v: Vector<T, N, S>) -> Self
Returns the wrapped input vector, assuming it is normalized.
Sourcepub fn to_unit_vec(&self) -> Vector<T, N, S>
pub fn to_unit_vec(&self) -> Vector<T, N, S>
Returns the unit vector that represents this direction.
Sourcepub fn to_point(&self) -> Point<T, N, S>
pub fn to_point(&self) -> Point<T, N, S>
Returns the point corresponding to this unit vector (a point on the unit sphere).
Sourcepub fn in_space<Target: Space>(self) -> Dir<T, N, Target>
pub fn in_space<Target: Space>(self) -> Dir<T, N, Target>
Reinterprets this direction as being in the space Target instead of
S. Before calling this, make sure this operation makes semantic sense
and don’t just use it to get rid of compiler errors.
Sourceimpl<T: Scalar, S: Space> Dir<T, 2, S>
impl<T: Scalar, S: Space> Dir<T, 2, S>
Sourcepub fn new(x: T, y: T) -> Selfwhere
T: Float,
pub fn new(x: T, y: T) -> Selfwhere
T: Float,
Creates a Dir by normalizing the vector specified by the given
coordinates.
Sourcepub const fn new_unchecked(x: T, y: T) -> Self
pub const fn new_unchecked(x: T, y: T) -> Self
Creates a Dir without checking that the given values form a unit
vector.
Sourceimpl<T: Scalar, S: Space> Dir<T, 3, S>
impl<T: Scalar, S: Space> Dir<T, 3, S>
Sourcepub fn new(x: T, y: T, z: T) -> Selfwhere
T: Float,
pub fn new(x: T, y: T, z: T) -> Selfwhere
T: Float,
Creates a Dir by normalizing the vector specified by the given
coordinates.
Sourcepub const fn new_unchecked(x: T, y: T, z: T) -> Self
pub const fn new_unchecked(x: T, y: T, z: T) -> Self
Creates a Dir without checking that the given values form a unit
vector.